==> openshift-model-config-6.6.2-sources.jar: io/fabric8/openshift/api/model/config/v1/ImageContentPolicyFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ImageContentPolicyFluent<A extends ImageContentPolicyFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public ImageContentPolicyFluent.MetadataNested<A> withNewMetadata();
  public ImageContentPolicyFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public ImageContentPolicyFluent.MetadataNested<A> editMetadata();
  public ImageContentPolicyFluent.MetadataNested<A> editOrNewMetadata();
  public ImageContentPolicyFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ImageContentPolicySpec getSpec();
  public ImageContentPolicySpec buildSpec();
  public A withSpec(ImageContentPolicySpec spec);
  public Boolean hasSpec();
  public ImageContentPolicyFluent.SpecNested<A> withNewSpec();
  public ImageContentPolicyFluent.SpecNested<A> withNewSpecLike(ImageContentPolicySpec item);
  public ImageContentPolicyFluent.SpecNested<A> editSpec();
  public ImageContentPolicyFluent.SpecNested<A> editOrNewSpec();
  public ImageContentPolicyFluent.SpecNested<A> editOrNewSpecLike(ImageContentPolicySpec item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<ImageContentPolicyFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,ImageContentPolicySpecFluent<ImageContentPolicyFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  
}

==> openshift-model-config-6.7.0-sources.jar: io/fabric8/openshift/api/model/config/v1/ImageContentPolicyFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ImageContentPolicyFluent<A extends ImageContentPolicyFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public ImageContentPolicyFluent.MetadataNested<A> withNewMetadata();
  public ImageContentPolicyFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public ImageContentPolicyFluent.MetadataNested<A> editMetadata();
  public ImageContentPolicyFluent.MetadataNested<A> editOrNewMetadata();
  public ImageContentPolicyFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ImageContentPolicySpec getSpec();
  public ImageContentPolicySpec buildSpec();
  public A withSpec(ImageContentPolicySpec spec);
  public Boolean hasSpec();
  public ImageContentPolicyFluent.SpecNested<A> withNewSpec();
  public ImageContentPolicyFluent.SpecNested<A> withNewSpecLike(ImageContentPolicySpec item);
  public ImageContentPolicyFluent.SpecNested<A> editSpec();
  public ImageContentPolicyFluent.SpecNested<A> editOrNewSpec();
  public ImageContentPolicyFluent.SpecNested<A> editOrNewSpecLike(ImageContentPolicySpec item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<ImageContentPolicyFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,ImageContentPolicySpecFluent<ImageContentPolicyFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  
}
